@@ -166,7 +166,7 @@ class ProxyHandler(HubOAuthenticated, WebSocketHandlerMixin):
         else:
             return host in self.host_whitelist
 
-    @web.authenticated
+    #@web.authenticated - handled in subclass
     async def proxy(self, host, port, proxied_path):
         '''
         This serverextension handles:
@@ -385,13 +385,16 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
     def __init__(self, *args, **kwargs):
         self.requested_port = 0
         self.mappath = {}
+
         super().__init__(*args, **kwargs)
 
-    def initialize(self, state, *args, **kwargs):
+    def initialize(self, state, authtype, *args, **kwargs):
         self.state = state
         if 'proc_lock' not in state:
             state['proc_lock'] = Lock()
 
+        self.authtype = authtype
+
         super().initialize(*args, **kwargs)
 
     name = 'process'
@@ -479,7 +482,10 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
                     raise
 
     @web.authenticated
-    async def proxy(self, port, path):
+    async def oauth_proxy(self, port, path):
+        return await self.core_proxy(port, path)
+
+    async def core_proxy(self, port, path):
         if not path.startswith('/'):
             path = '/' + path
 
@@ -497,6 +503,12 @@ class SuperviseAndProxyHandler(LocalProxyHandler):
 
         return await super().proxy(self.port, path)
 
+    async def proxy(self, port, path):
+        if self.authtype == 'oauth':
+            return await self.oauth_proxy(port, path)
+        else:
+            return await self.core_proxy(port, path)
+
     async def http_get(self, path):
         self.log.info('SuperviseAndProxyHandler http_get {} {}'.format(self.port, path))
         return await self.proxy(self.port, path)
@@ -547,7 +559,7 @@ def _make_serverproxy_handler(name, command, environment, timeout, absolute_url,
             }
         @property
         def base_url(self):
-            return '/' #self.settings.get('base_url', '/')
+            return self.settings.get('base_url', '/')
 
         @property
         def hub_users(self):
